@@ -1,10 +1,10 @@
 "plot.emaxsimB" <-
-function(x,id=x$idmax,difPlacebo= TRUE,...)
+function(x,id=x$idmax,plotDif= TRUE,...)
 {
 	### produces qq plot for z-statistics for primary comparison of
 	### idmax dose with placebo
 	
-	if(difPlacebo){
+	if(plotDif){
 		fitdifv<-x$fitpredv-x$fitpredv[,1]
 		fitdifP<-x$predpop-x$predpop[,1]
     }else{
@@ -14,8 +14,8 @@ function(x,id=x$idmax,difPlacebo= TRUE,...)
 
     doselev<-x$genObj$genP$doselev
     xx<-qnorm(ppoints(nrow(fitdifv)))
-    if(difPlacebo)y<-(fitdifv[, id] - fitdifP[,id])/x$sedifv[, id]
-    if(!difPlacebo)y<-(fitdifv[, id] - fitdifP[,id])/x$sepredv[, id]
+    if(plotDif)y<-(fitdifv[, id] - fitdifP[,id])/x$sedifv[, id]
+    if(!plotDif)y<-(fitdifv[, id] - fitdifP[,id])/x$sepredv[, id]
     ord<-order(y)
     y<-y[ord]
     plot(xx,y,
@@ -23,7 +23,7 @@ function(x,id=x$idmax,difPlacebo= TRUE,...)
          main=paste("QQ plot of population-Z for dose=",
          					 doselev[id],sep=""),
     		 xlab="Theoretical Quantiles",ylab="Sample Quantiles",... )
-    if(difPlacebo)mtext('Difference with placebo')
+    if(plotDif)mtext('Difference with placebo')
     points(xx,y)
     abline(0, 1)
     cat("Population-Z is (posterior mean - pop)/(posterior sd)\n")	
