@@ -30,6 +30,6 @@
 	print(tmp,quote= FALSE) 
 	
 	
-	return(invisible())
+	return(invisible(tmp))
 }
 
